slang.core — slang 0.1.0 documentation

# slang.core

Core functionality

class `slang.core.` `Snipper`(wf_to_chks: NewType.<locals>.new_type = <function mk_chunker.<locals>.chunker>, chk_to_fv: NewType.<locals>.new_type = <function rms_zcr>, fv_to_snip: NewType.<locals>.new_type = <function rms_zcr_quantizer>)

  A base class that implements the wf->chk->fv->snip pipeline. Default functions for wf_to_chk (a.k.a. chunker), chk_to_fv (a.k.a. featurizer) and fv_to_snip (a.k.a. nipper) are given, but usually the user should specify these, and usually these are learned from data.